cdn-definitions
===============

Data definitions for Red Hat's content delivery network.

[![Build Status](https://travis-ci.org/release-engineering/cdn-definitions.svg?branch=master)](https://travis-ci.org/release-engineering/cdn-definitions)
[![Coverage Status](https://coveralls.io/repos/github/release-engineering/cdn-definitions/badge.svg?branch=master)](https://coveralls.io/github/release-engineering/cdn-definitions?branch=master)

- [Source](https://github.com/release-engineering/cdn-definitions)
- [Documentation](https://release-engineering.github.io/cdn-definitions/)
- [PyPI](https://pypi.org/project/cdn-definitions)

This project maintains a dataset defining and influencing certain behaviors
of Red Hat's CDN, such as aliases between paths.

To get an idea of the type of data maintained within this project, you can
[browse the latest published dataset](https://release-engineering.github.io/cdn-definitions/data.yaml).

See the
[User Guide](https://release-engineering.github.io/cdn-definitions/userguide.html#) for more information
if you are interested in consuming this data, or the
[Maintenance Guide](https://release-engineering.github.io/cdn-definitions/maint.html#) if you need
to make changes.

License
-------

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
